# eric7.EricWidgets.EricLineEditButton

Module implementing a button class to be used with EricLineEdit.

### Global Attributes

None

### Classes

EricLineEditButton | Class implementing a button to be used with EricLineEdit.

### Functions

None

## EricLineEditButton

Class implementing a button to be used with EricLineEdit.

### Derived from

QAbstractButton

### Class Attributes

None

### Class Methods

None

### Methods

EricLineEditButton | Constructor
__clicked | Private slot to handle a button click.
menu | Public method to get a reference to the menu.
paintEvent | Protected method handling a paint event.
setIcon | Public method to set the button icon.
setMenu | Public method to set the button menu.

### Static Methods

None

#### EricLineEditButton (Constructor)

EricLineEditButton(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### EricLineEditButton.__clicked

__clicked()

Private slot to handle a button click.

#### EricLineEditButton.menu

menu()

Public method to get a reference to the menu.

Return:
  reference to the associated menu

Return Type:
  QMenu

#### EricLineEditButton.paintEvent

paintEvent(_evt)

Protected method handling a paint event.

_evt (QPaintEvent)
  reference to the paint event (unused)

#### EricLineEditButton.setIcon

setIcon(icon)

Public method to set the button icon.

icon (QIcon)
  icon to be set

#### EricLineEditButton.setMenu

setMenu(menu)

Public method to set the button menu.

menu (QMenu)
  reference to the menu

Up